# Experimentum Change Log 📝

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/) and this project adheres to [Semantic Versioning](http://semver.org/).


## [Unreleased]

## [1.0.1] - 2019-04-28
### Fixed
- fixed Missing templates issue #8

## [1.0.0] - 2019-04-17
### Added
- Initial public release

[Unreleased]: https://github.com/pascalkleindienst/experimentum/compare/v1.0.0...HEAD
[1.0.0]: https://github.com/pascalkleindienst/experimentum/releases/tag/v1.0.0
[1.0.1]: https://github.com/pascalkleindienst/experimentum/releases/tag/v1.0.1
[1.0.2]: https://github.com/pascalkleindienst/experimentum/releases/tag/v1.0.2